@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2024 Leandro Nini
+ * Copyright 2011-2025 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -253,7 +253,7 @@ int ConsolePlayer::args(int argc, const char *argv[])
                     err = true;
                 else
                 {
-                    const int voice = atoi(&argv[i][2]);
+                    const unsigned int voice = atoi(&argv[i][2]);
                     if (voice > 0 && voice <= m_mute_channel.size())
                         m_mute_channel[voice-1] = true;
                 }
@@ -267,7 +267,7 @@ int ConsolePlayer::args(int argc, const char *argv[])
                     err = true;
                 else
                 {
-                    const int chip = atoi(&argv[i][2]);
+                    const unsigned int chip = atoi(&argv[i][2]);
                     if (chip > 0 && chip <= m_mute_samples.size())
                         m_mute_samples[chip-1] = true;
                 }
