@@ -37,6 +37,7 @@
 #include "audio/null/null.h"
 #include "IniConfig.h"
 
+#include "setting.h"
 #include "sidlib_features.h"
 
 #include <string>
@@ -153,17 +154,19 @@ private:
     IniConfig          m_iniCfg;
     SidDatabase        m_database;
 
-    double             m_fcurve;
+    Setting<double>    m_fcurve;
 #ifdef FEAT_FILTER_RANGE
-    double             m_frange;
+    Setting<double>    m_frange;
 #endif
 
 #ifdef FEAT_CW_STRENGTH
     SidConfig::sid_cw_t m_combinedWaveformsStrength;
 #endif
 
+#ifdef FEAT_REGS_DUMP_SID
     uint8_t            m_registers[3][32];
     uint16_t*          m_freqTable;
+#endif
 
     // Display parameters
     uint_least8_t      m_quietLevel;
